@@ -33,12 +33,14 @@
 #include <ne_utils.h>
 #include <ne_request.h>
 #include <ne_dates.h>
-#include <glib.h>
+#include <ne_auth.h>
 
 #include "httpfetch.h"
 
 #ifdef DEBUG
-#define DEBUG_PRINT(...) g_message("httpfetch** " __VA_ARGS__);
+#define DEBUG_PRINT(...) printf("httpfetch** ");\
+                         printf("%s(%u): ", __func__, __LINE__); \
+                         printf(__VA_ARGS__);printf("\n");
 #else
 #define DEBUG_PRINT(...)
 #endif
@@ -90,25 +92,56 @@ buffer_append(void* userdata, const char* buff, size_t len)
 	return;
 }
 
-/*
-static void
-buffer_append(void* userdata, const char* buff, size_t len)
+static int
+serverauth(void *userdata, const char *realm, int attempt,
+			char *username, char *password)
 {
-	GString* strBuff = (GString*)userdata;
+	char* tok;
+	char* authstr;
+	char* strTemp;
+
+	if(!userdata || *(char*)userdata == '\0'){
+		DEBUG_PRINT("userdata is invalid");
+		return 1;
+	}
+
+	if(attempt > 0){
+		DEBUG_PRINT("attempt > 0");
+		return 1;
+	}
 	
-	if(len == 0)
-		return;
+	authstr = strdup(userdata);
+	strTemp = authstr;
 
-	g_string_append_len(strBuff, buff, len);
+	DEBUG_PRINT(authstr);
 
-	return;
+	if((tok = ne_token(&authstr, ':'))){
+		strcpy(username, tok);
+		DEBUG_PRINT("username: %s", username);
+	}
+	
+	if(!authstr){
+		DEBUG_PRINT("authinfo invalid");
+		return 1;
+	}
+	
+	if((tok = ne_token(&authstr, ':'))){
+		strcpy(password, tok);
+		DEBUG_PRINT("password: %s", password);
+	}
+	
+	free(strTemp);
+
+	return 0;
 	
 }
-*/
 
-/*int
-httpfetch(const char* strURI, char* const buff, int bufflen, 
-time_t tmModified, time_t* ptmRetModified)*/
+/* trusting the cert without verification */
+static int 
+trustcert(void *userdata, int failures, const ne_ssl_certificate *cert)
+{
+	return 0; 
+}
 
 int
 httpfetch(const char* strURI, char** ppBuff, 
@@ -124,7 +157,7 @@ httpfetch(const char* strURI, char** ppBuff,
 	*ppBuff = NULL;
 
 	if(!strURI || !ppBuff){
-		g_error("invalid arg");
+		DEBUG_PRINT("invalid arg");
 		return HF_ERROR;
 	}
 	
@@ -157,6 +190,16 @@ httpfetch(const char* strURI, char** ppBuff,
 	/* Create session. */
     ne_sess = ne_session_create(uri.scheme, uri.host, uri.port);
 
+	ne_set_useragent(ne_sess, PACKAGE);
+
+	ne_set_server_auth(ne_sess, serverauth, uri.authinfo);
+
+	/* https setting */
+	if(strcmp("https", uri.scheme) == 0){
+		ne_ssl_trust_default_ca(ne_sess);
+		ne_ssl_set_verify(ne_sess, trustcert, NULL);
+	}
+	
 	/* proxy setting */
 	init_proxy(ne_sess);
 
@@ -164,7 +207,7 @@ httpfetch(const char* strURI, char** ppBuff,
 
 	/* Create request. */
 	ne_req = ne_request_create(ne_sess, "GET", uri.path);
-	ne_add_response_body_reader(ne_req, ne_accept_always, (ne_block_reader)buffer_append, ne_buf);
+	ne_add_response_body_reader(ne_req, ne_accept_2xx, (ne_block_reader)buffer_append, ne_buf);
 
 	ne_add_response_header_handler(ne_req, "Last-Modified", ne_duplicate_header,ne_header_buf);
 	
