@@ -3,12 +3,11 @@
 
 #include <time.h>
 
-#define MAX_FETCH_LEN (100 * 1024) /* 100kB */
 #define MAX_DATETIME_LEN 256
 
 #define HF_ERROR (-1)
 #define HF_NOT_MODIFIED (-2)
 
-int httpfetch(const char* strURI, char* const buff, int bufflen, time_t tmModified, time_t* ptmRetModified);
+int httpfetch(const char* strURI, char** buff, time_t tmModified, time_t* ptmRetModified);
 
 #endif
