@@ -2103,7 +2103,7 @@ newsreader_create_options (Control * control, GtkContainer * container,
 
 	newsreader = (newsreader_t*) control->data;
 
-    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
 	(void)newsreader_CreateConfigGUI(GTK_WIDGET(container), &newsreader->oGUI);
 
@@ -2225,7 +2225,7 @@ create_initial_menu(newsreader_t* newsreader)
 
 
 	itemImage = gtk_image_new_from_stock("gtk-dialog-info", GTK_ICON_SIZE_MENU);
-	itemAbout = gtk_image_menu_item_new_with_mnemonic (_("_About"));
+	itemAbout = gtk_image_menu_item_new_with_mnemonic (_("_About..."));
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(itemAbout), GTK_WIDGET(itemImage));
 
 	gtk_widget_show(itemAbout);
@@ -2471,7 +2471,7 @@ newsreader_set_size (Control *control, int size)
 G_MODULE_EXPORT void
 xfce_control_class_init (ControlClass * cc)
 {
-    xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
+    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
     /* Must be present: 
        - name            : unique id 
